diff --git a/index.html b/index.html
index 886cfa1..680d95c 100644
--- a/index.html
+++ b/index.html
@@ -1,4 +1,4 @@
-
+
@@ -287,8 +287,8 @@
- Alpha release v0.0.16.1
- v20230709.002
+ Alpha release v0.0.16.2
+ v20230715.001
-
+
diff --git a/js/ui/tool/dream.js b/js/ui/tool/dream.js
index 0ccb20b..645989c 100644
--- a/js/ui/tool/dream.js
+++ b/js/ui/tool/dream.js
@@ -62,12 +62,9 @@ const _monitorProgress = (bb, oncheck = null) => {
}
const timeSpent = performance.now() - init;
- setTimeout(
- () => {
- if (running) _checkProgress();
- },
- Math.max(0, minDelay - timeSpent)
- );
+ setTimeout(() => {
+ if (running) _checkProgress();
+ }, Math.max(0, minDelay - timeSpent));
};
_checkProgress();
@@ -2028,11 +2025,11 @@ const dreamTool = () =>
"Outpaint Type",
{
0: "fill",
- 1: "original (AVOID)",
- 2: "latent noise (suggested)",
+ 1: "original (SDXL)",
+ 2: "latent noise (SD1.x/2.x)",
3: "latent nothing",
},
- 2, // AVOID ORIGINAL FOR OUTPAINT OR ELSE but we still give you the option because we love you
+ 2, // AVOID ORIGINAL FOR OUTPAINT OR ELSE but we still give you the option because we love you and because it seems to work better for SDXL
() => {
stableDiffusionData.outpainting_fill = state.outpainting_fill;
}